#!/bin/sh

# This file is hereby placed in the public domain.

[ -z "$DEPENDFILE" ] && DEPENDFILE=.depend
${CC-cc} $CPPFLAGS -MM "$@" > "$DEPENDFILE"
